<?php

namespace Thinkpool;

use WP_Error;

class ApiClient
{

    const SUBSCRIBER_ENDPOINT = "https://api.probaho.com.bd/subscribers/user/add";
    const TRANSACTIONAL_ENDPOINT = "https://api.probaho.com.bd/transact/create";


    private $headers = array(
        'Content-type' => "application/x-www-form-urlencoded"
    );

    public function __construct($public_key)
    {
        $this->headers['public-key'] = $public_key;
    }

    /**
     * Create or update Probaho subscriber by syncing WP User
     *
     * @return array|WP_Error The response or WP_Error on failure.
     */
    public function create_update_subscriber(string $subscriber_name, string $subscriber_email, string $list_unique_id, string $list_name_tag)
    {
        $data = array(
            $list_name_tag => $subscriber_name,
            'email' => $subscriber_email,
            'list' => $list_unique_id
        );
        $args = array(
            'headers' => $this->headers,
            'body' => $data
        );
        return wp_remote_post($this::SUBSCRIBER_ENDPOINT, $args);
    }

    /**
     * Send Transactional Email via Probaho Transactional API endpoint
     */
    public function send_transactional_mail($to, $sender_email, $sender_name, $message, $subject, $from, array $attachment)
    {
        return wp_remote_post($this::TRANSACTIONAL_ENDPOINT, $this->prepare_email($to, $sender_email, $sender_name, $message, $subject, $from, $attachment));
    }

    /**
     * Prepare the email data object for Sending
     */
    private function prepare_email($to, $sender_email, $sender_name, $message, $subject, $from, array $attachment)
    {
        $data = array(
            'to_name' => $to,
            'to_email' => $to,
            'from_name' => $sender_name,
            'subject' => $subject,
            'body' => $message,
            'from_email' => $sender_email,
            'reply_to_name' => $from,
            'reply_to_email' => $sender_email,
            'attachment' => $attachment
        );
        return array(
            'headers' => $this->headers,
            'body' => $data
        );
    }
}
