<?php

namespace Thinkpool;

use WP_Error;

class TransactionalEmail
{
    /**
     * User's setting for Transactional Email
     */
    private $transactional_settings;

    /**
     * Probaho API client object
     */
    private $api_client;

    function __construct(array $probaho_transactional, ApiClient $api_client)
    {
        $this->transactional_settings =  $probaho_transactional;
        $this->api_client =  $api_client;
        // override wp_mail() with Probaho mailer
        add_filter('pre_wp_mail', array($this, 'probaho_mailer'), 10, 2);
    }

    /**
     * return = true is set to short circuit wp_mail() using pre_wp_mail filter
     */
    function probaho_mailer($return = true, $atts)
    {
        if (isset($atts)) {
            $message    = $atts['message'];
            $to         = $atts['to'];
            $subject    = $atts['subject'];
            $attachment = array();

            if (isset($atts['attachment'])) {

                // if there are multiple attachment as array
                if (is_array($atts)) {
                    $attachment = $this->process_attachment($atts);
                } else {
                    // single attachment
                    $attachment = $this->create_single_attachment($atts['attachment']);
                }
            }

            // Make the message HTML email for better view
            if (!Utilities::isHTML($message)) {
                $message = nl2br($message);
            }

            // use template only when it is enabled
            $message = Utilities::make_html_message($this->transactional_settings['transactional_template'], get_bloginfo('name'), $message, $footer = 'Sent by
        <a href="https://probaho.com.bd"><u>Probaho</u></a>.');

            $return = $this->send_mail($to, $subject, $message, $attachment);

            if (is_wp_error($return)) {
                // error_log('Email through Probaho not sent, Reason: ' . $return->get_error_message());
                return false;
            }
            return true;
        }
        return new WP_Error("attribute must not be blank");
    }

    function send_mail($to, $subject, $message, $attachment)
    {
        $sender_email = $this->transactional_settings['sender_email'];
        $sender_name = $this->transactional_settings['sender_name'];

        // if its a comma separated list of email address, convert to an array
        if (strpos($to, ",")) {
            $to = explode(",", $to);
        }

        // check if there are multiple receipients, if so send to each of them
        if (is_array($to)) {
            foreach ($to as $single_receipient) {
                // push each mail to Probaho API gateway, we don't care about its output
                $this->api_client->send_transactional_mail(
                    $to,
                    $sender_email,
                    $sender_name,
                    $message,
                    $subject,
                    get_bloginfo('name'),
                    $attachment
                );
            }
            return true;
        } else {
        }

        // When its a single receipient
        $response = $this->api_client->send_transactional_mail(
            $to,
            $this->transactional_settings['sender_email'],
            $this->transactional_settings['sender_name'],
            $message,
            $subject,
            get_bloginfo('name'),
            $attachment
        );

        $response_code = wp_remote_retrieve_response_code($response);
        $response_body = json_decode(wp_remote_retrieve_body($response));

        if ($response_body->status == "error") {
            return new WP_Error($response_code, $response_body->error);
        }
        return true;
    }

    // Process attachment data
    function create_single_attachment($atts): array
    {
        return array(
            'type' => mime_content_type($atts),
            'name' => basename($atts),
            'data' => base64_encode((string)file_get_contents($atts))
        );
    }
    /**
     * For processing array of attachments
     */
    function process_attachment($atts)
    {
        $attachment = [];
        // if there are multiple attachment as array
        if (is_array($atts['attachment'])) {
            foreach ($atts['attachment'] as $single_filepath) {
                $attachment[] = $this->create_single_attachment($single_filepath);
            }
        }
        return $attachment;
    }
}
