<?php

namespace Thinkpool;

use WP_User;

class UserSync
{

    /**
     * User's setting for User Sync Settings
     */
    private $user_sync_settings;

    /**
     * Probaho API client object
     */
    private $api_client;

    private $is_user_sync_enabled;

    private $list_unique_id;

    private $list_name_tag;

    public function __construct($probaho_user_sync, $api_client)
    {
        $this->user_sync_settings =  $probaho_user_sync;
        $this->api_client = $api_client;

        $this->is_user_sync_enabled = $probaho_user_sync['enable_user_sync'];
        $this->list_unique_id = $probaho_user_sync['user_sync_list'];
        $this->list_name_tag = $probaho_user_sync['name_tag'];

        // for syncing users
        add_action('user_register', array($this, 'track_user_login'), 10, 1);
        add_action('wp_login', array($this, 'on_first_login'), 10, 2);
    }

    /**
     * Insert 1 in usermeta to indicate that user never logged in
     */
    function track_user_login($user_id)
    {
        if ($this->is_user_sync_enabled) {
            add_user_meta($user_id, 'prefix_first_login', '1', true);
        }
    }

    function on_first_login($user_login, WP_USER $user)
    {
        $user_id = $user->ID;

        // On login, Handle user who registered before this plugin activateion
        if (!metadata_exists('user', $user_id, 'prefix_first_login')) {

            $this->user_to_subscriber($user);
            update_user_meta($user_id, 'prefix_first_login', '0');
        } else {
            // Handle new user after activation of this plugin
            // getting prev. saved meta
            $first_login = get_user_meta($user_id, 'prefix_first_login', true);

            // if first time login
            if ($first_login == '1') {

                $this->user_to_subscriber($user);

                // update meta after first login to '0'
                update_user_meta($user_id, 'prefix_first_login', '0');
            }
        }
    }

    /**
     * Send User detail to probaho endpoint
     */
    function user_to_subscriber(WP_USER $user)
    {
        $response = $this->api_client->create_update_subscriber($user->display_name, $user->user_email, $this->list_unique_id, $this->list_name_tag);

        Utilities::handleError($response, "User to subscriber didn't succeed");
    }
}
