<?php

namespace Thinkpool;

class Utilities
{

    /**
     * Check if the email is HTML or plaintext
     * @return boolean
     */
    public static function isHTML($string): bool
    {
        return $string != strip_tags($string) ? true : false;
    }

    /**
     * Log API call errors
     */
    public static function handleError($response, $log_Message)
    {
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            $error = $log_Message . $error_message;
            error_log($error);
        }
    }

    /**
     * Convert WP email message to html and add href tag to links
     */
    public static function make_html_message($html, $sitename, $message, $footer)
    {
        $message = preg_replace('!(((f|ht)tp(s)?://)[-a-zA-Zа-яА-Я()0-9@:%_+.~#?&;//=]+)!i', '<a target="blank" rel="nofollow" href="$1" target="_blank">$1</a>', $message);

        $to_replace = array(
            '%sitename%',
            '%message%',
            '%footer%'
        );
        $replace_with = array(
            $sitename,
            $message,
            $footer
        );
        return str_replace($to_replace, $replace_with, $html);
    }

    /**
     * Produce default template for Transactional Email.
     * If you choose to customize this, please be sure to include the following tags:
     * <strong> %sitename%, %message% & %footer% </strong>
     * @return string
     */
    public static function probaho_get_default_html(): string
    {
        // return <<<EOD
        //         EOD;
        $location = plugin_dir_path(__DIR__). 'template/default.html';
        $template = fopen($location, "r") or die("some file is missing. Pleae reinstall the plugin");
        $result = fread($template, filesize($location));
        fclose($template);
        return <<<END
        $result
        END;
    }
}
